==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/ListTagsForResourceRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class ListTagsForResourceRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.ListTagsForResourceRequest
      .builder()
      .resourceArn(__string.unwrap(resourceArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.mediatailor.model.ListTagsForResourceRequest.wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.ListTagsForResourceRequest =
      zio.aws.mediatailor.model.ListTagsForResourceRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.ListTagsForResourceRequest
  ) extends zio.aws.mediatailor.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceArn: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.resourceArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.ListTagsForResourceRequest
  ): zio.aws.mediatailor.model.ListTagsForResourceRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.19.7.1-sources.jar: zio/aws/mediatailor/model/ListTagsForResourceRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class ListTagsForResourceRequest(resourceArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.ListTagsForResourceRequest = {
    import ListTagsForResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.ListTagsForResourceRequest
      .builder()
      .resourceArn(resourceArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.ListTagsForResourceRequest.ReadOnly =
    zio.aws.mediatailor.model.ListTagsForResourceRequest.wrap(buildAwsValue())
}
object ListTagsForResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.ListTagsForResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.ListTagsForResourceRequest =
      zio.aws.mediatailor.model.ListTagsForResourceRequest(resourceArn)
    def resourceArn: __string
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.ListTagsForResourceRequest
  ) extends zio.aws.mediatailor.model.ListTagsForResourceRequest.ReadOnly {
    override val resourceArn: __string = impl.resourceArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.ListTagsForResourceRequest
  ): zio.aws.mediatailor.model.ListTagsForResourceRequest.ReadOnly =
    new Wrapper(impl)
}
